@@ -24,22 +24,27 @@ class Donor:
     disease: str
 
 
-def parse_ped(ped_file) -> typing.Iterable[Donor]:
-    """Parse a given PED file and yield each line as a Donor."""
+def parse_ped(ped_file) -> typing.List[Donor]:
+    """Parse a given PED file and return ``Donor`` objects."""
+    lines = []
     for line in ped_file.readlines():
         line = re.split(r"\s+", line.rstrip())[:6]
 
         if line[0].startswith("#"):
             continue
 
-        if not len(line) == 6:
+        if not len(line) == 6:  # pragma: no cover
             raise Exception("PED file not complete.")
 
-        yield Donor(
-            family_id=line[0],
-            name=line[1],
-            father_name=line[2],
-            mother_name=line[3],
-            sex=SEX_MAP.get(line[4], "unknown"),
-            disease=DISEASE_MAP.get(line[5], "unknown"),
+        lines.append(
+            Donor(
+                family_id=line[0],
+                name=line[1],
+                father_name=line[2],
+                mother_name=line[3],
+                sex=SEX_MAP.get(line[4], "unknown"),
+                disease=DISEASE_MAP.get(line[5], "unknown"),
+            )
         )
+
+    return lines
